# dendri

[![pytest](https://github.com/GDITHealth/dendri/workflows/pytest/badge.svg)](https://github.com/GDITHealth/dendri/actions?query=workflow%3Apytest)
[![Linting](https://github.com/GDITHealth/dendri/workflows/Linting/badge.svg)](https://github.com/GDITHealth/dendri/actions?query=workflow%3ALinting)
[![License](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/GDITHealth/dendri/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Common Health Care feature engineering algorithms implemented in Python.

[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/GDITHealth/dendri)
